@@ -4,9 +4,8 @@
 # the root in the LICENSE file
 #
 # -*- coding: utf-8 -*-
-"""Executed when aacgmv2 is invoked with python -m aacgmv2"""
+"""Executed when aacgmv2 is invoked with python -m aacgmv2."""
 
-from __future__ import division, print_function, absolute_import
 
 import argparse
 import datetime as dt
@@ -15,18 +14,9 @@ import sys
 
 import aacgmv2
 
-if sys.version_info.major >= 3:
-    # Python 3
-    STDIN = sys.stdin.buffer
-    STDOUT = sys.stdout.buffer
-else:
-    # Python 2
-    STDIN = sys.stdin
-    STDOUT = sys.stdout
-
 
 def main():
-    """Entry point for the script"""
+    """Entry point for the script."""
 
     desc = 'Converts between geographical coordinates, AACGM-v2, and MLT'
     parser = argparse.ArgumentParser(description=desc)
@@ -47,9 +37,10 @@ def main():
     desc = 'input file (stdin if none specified)'
     for pp in [parser_convert, parser_convert_mlt]:
         pp.add_argument('-i', '--input', dest='file_in', metavar='FILE_IN',
-                        type=argparse.FileType('r'), default=STDIN, help=desc)
+                        type=argparse.FileType('r'), default=sys.stdin.buffer,
+                        help=desc)
         pp.add_argument('-o', '--output', dest='file_out', metavar='FILE_OUT',
-                        type=argparse.FileType('wb'), default=STDOUT,
+                        type=argparse.FileType('w'), default=sys.stdout.buffer,
                         help='output file (stdout if none specified)')
 
     desc = 'date for magnetic field model (1900-2020, default: today)'
@@ -93,6 +84,7 @@ def main():
             date = dt.date.today()
         else:
             date = dt.datetime.strptime(args.date, '%Y%m%d')
+
         code = aacgmv2.convert_bool_to_bit(a2g=args.a2g, trace=args.trace,
                                            allowtrace=args.allowtrace,
                                            badidea=args.badidea,
@@ -112,6 +104,12 @@ def main():
 
         np.savetxt(args.file_out, out, fmt='%.8f')
 
+    # If not a pipe to STDOUT or STDERR, ensure the file is closed
+    not_pipe = ((args.file_out.name.find('stdout') < 0)
+                & (args.file_out.name.find('stderr') < 0))
+    if not_pipe:
+        args.file_out.close()
+
 
 if __name__ == '__main__':
     sys.exit(main())
