@@ -1,6 +1,3 @@
-# -*- coding: utf-8 -*-
-from __future__ import division, absolute_import, unicode_literals
-
 import logging
 import numpy as np
 import os
@@ -10,21 +7,23 @@ import pytest
 import aacgmv2
 
 
-# @pytest.mark.skip(reason="Not meant to be run alone")
-class TestModuleStructure:
-    def setup(self):
+class TestModuleStructure(object):
+    """Class for testing the module structure."""
 
+    def setup_method(self):
+        """Create a clean test environment."""
         # Define the acceptable output
         if not hasattr(self, "reference_list"):
             self.reference_list = list()
         if not hasattr(self, "module_name"):
             self.module_name = None
 
-    def teardown(self):
+    def teardown_method(self):
+        """Clean up the test environment."""
         del self.reference_list, self.module_name
 
     def test_module_existence(self):
-        """Test the module existence"""
+        """Test the module existence."""
 
         # Get the dictionary of functions for the specified module
         retrieved_dict = aacgmv2.__dict__
@@ -38,7 +37,7 @@ class TestModuleStructure:
             assert isinstance(retrieved_dict, dict)
 
     def test_module_functions(self):
-        """Test module function structure"""
+        """Test module function structure."""
 
         # Get the dictionary of functions for the specified module
         retrieved_dict = aacgmv2.__dict__
@@ -62,7 +61,7 @@ class TestModuleStructure:
             assert len(retrieved_list) == len(self.reference_list)
 
     def test_modules(self):
-        """Test module submodule structure"""
+        """Test module submodule structure."""
 
         if self.module_name is None:
             assert True
@@ -78,67 +77,82 @@ class TestModuleStructure:
 
 
 class TestDepStructure(TestModuleStructure):
-    def setup(self):
+    """Test the deprecated structure."""
+
+    def setup_method(self):
+        """Create a clean test environment."""
         self.module_name = None
         self.reference_list = ["subsol", "igrf_dipole_axis", "gc2gd_lat"]
 
-    def teardown(self):
+    def teardown_method(self):
+        """Clean up the test environment."""
         del self.module_name, self.reference_list
 
     def test_dep_existence(self):
-        """ Test the deprecated functions"""
+        """Test the deprecated functions."""
         self.module_name = "deprecated"
         self.test_module_existence()
 
     def test_dep_functions(self):
-        """ Test the deprecated functions"""
+        """Test the deprecated functions."""
         self.module_name = "deprecated"
         self.test_module_functions()
 
 
 class TestUtilsStructure(TestModuleStructure):
-    def setup(self):
+    """Test the utility structure."""
+
+    def setup_method(self):
+        """Create a clean test environment."""
         self.module_name = None
         self.reference_list = ["subsol", "igrf_dipole_axis", "gc2gd_lat"]
 
-    def teardown(self):
+    def teardown_method(self):
+        """Clean up the test environment."""
         del self.module_name, self.reference_list
 
     def test_dep_existence(self):
-        """ Test the utility functions"""
+        """Test the utility functions."""
         self.module_name = "utils"
         self.test_module_existence()
 
     def test_dep_functions(self):
-        """ Test the utility functions"""
+        """Test the utility functions."""
         self.module_name = "utils"
         self.test_module_functions()
 
 
 class TestCStructure(TestModuleStructure):
-    def setup(self):
+    """Test the C structure."""
+
+    def setup_method(self):
+        """Create a clean test environment."""
         self.module_name = None
         self.reference_list = ["set_datetime", "convert", "inv_mlt_convert",
                                "inv_mlt_convert_yrsec", "mlt_convert",
                                "mlt_convert_yrsec", "inv_mlt_convert_arr",
                                "mlt_convert_arr", "convert_arr"]
 
-    def teardown(self):
+    def teardown_method(self):
+        """Clean up the test environment."""
         del self.module_name, self.reference_list
 
     def test_c_existence(self):
-        """ Test the C module existence"""
+        """Test the C module existence."""
         self.module_name = "_aacgmv2"
         self.test_module_existence()
 
     def test_c_functions(self):
-        """ Test the C functions"""
+        """Test the C functions."""
         self.module_name = "_aacgmv2"
         self.test_module_functions()
 
 
 class TestPyStructure(TestModuleStructure):
-    def setup(self):
+    """Test the Python structure."""
+
+    def setup_method(self):
+        """Create a clean test environment."""
         self.module_name = None
         self.reference_list = ["convert_bool_to_bit", "convert_str_to_bit",
                                "convert_mlt", "convert_latlon", "test_height",
@@ -146,35 +160,40 @@ class TestPyStructure(TestModuleStructure):
                                "get_aacgm_coord_arr", "set_coeff_path",
                                "test_time"]
 
-    def teardown(self):
+    def teardown_method(self):
+        """Clean up the test environment."""
         del self.module_name, self.reference_list
 
     def test_py_existence(self):
-        """ Test the python module existence"""
+        """Test the python module existence."""
         self.module_name = "wrapper"
         self.test_module_existence()
 
     def test_py_functions(self):
-        """ Test the python functions"""
+        """Test the python functions."""
         self.module_name = "wrapper"
         self.test_module_functions()
 
 
 class TestTopStructure(TestModuleStructure):
-    def setup(self):
+    """Test the top-level structure."""
+
+    def setup_method(self):
+        """Create a clean test environment."""
         self.module_name = None
         self.reference_list = list()
 
-    def teardown(self):
+    def teardown_method(self):
+        """Clean up the test environment."""
         del self.module_name, self.reference_list
 
     def test_top_existence(self):
-        """ Test the top level existence"""
+        """Test the top level existence."""
         self.module_name = "aacgmv2"
         self.test_module_existence()
 
     def test_top_functions(self):
-        """ Test the deprecated functions"""
+        """Test the deprecated functions."""
         self.module_name = "aacgmv2"
         self.reference_list = ["convert_bool_to_bit", "convert_str_to_bit",
                                "convert_mlt", "convert_latlon",
@@ -183,15 +202,18 @@ class TestTopStructure(TestModuleStructure):
         self.test_module_functions()
 
     def test_top_modules(self):
-        """ Test the deprecated functions"""
+        """Test the deprecated functions."""
         self.module_name = "aacgmv2"
         self.reference_list = ["_aacgmv2", "wrapper", "utils",
                                "deprecated", "__main__"]
         self.test_modules()
 
 
-class TestTopVariables:
-    def setup(self):
+class TestTopVariables(object):
+    """Test the top-level variables."""
+
+    def setup_method(self):
+        """Create a clean test environment."""
         self.alt_limits = {"coeff": 2000.0, "trace": 6378.0}
         self.coeff_file = {"coeff": os.path.join("aacgmv2", "aacgmv2",
                                                  "aacgm_coeffs",
@@ -199,14 +221,24 @@ class TestTopVariables:
                            "igrf": os.path.join("aacgmv2", "aacgmv2",
                                                 "magmodel_1590-2020.txt")}
 
-    def teardown(self):
+    def teardown_method(self):
+        """Clean up the test environment."""
         del self.alt_limits, self.coeff_file
 
     @pytest.mark.parametrize("env_var,fkey",
                              [(aacgmv2.AACGM_v2_DAT_PREFIX, "coeff"),
                               (aacgmv2.IGRF_COEFFS, "igrf")])
     def test_top_parameters(self, env_var, fkey):
-        """Test module constants"""
+        """Test module constants.
+
+        Parameters
+        ----------
+        env_var : str
+            Environment variable
+        fkey : str
+            Corresponding dict key
+
+        """
 
         if env_var.find(self.coeff_file[fkey]) < 0:
             raise AssertionError("Bad env variable: {:} not {:}".format(
@@ -216,7 +248,16 @@ class TestTopVariables:
                              [(aacgmv2.high_alt_coeff, "coeff"),
                               (aacgmv2.high_alt_trace, "trace")])
     def test_high_alt_variables(self, alt_var, alt_ref):
-        """ Test that module altitude limits exist and are appropriate"""
+        """Test that module altitude limits exist and are appropriate.
+
+        Parameters
+        ----------
+        alt_var : float
+            Altitude variable with float output
+        alt_ref : str
+            Output dict key
+
+        """
 
         if not isinstance(alt_var, type(self.alt_limits[alt_ref])):
             raise TypeError("Altitude limit variable isn't a float")
@@ -225,7 +266,7 @@ class TestTopVariables:
                                        decimal=4)
 
     def test_module_logger(self):
-        """ Test the module logger instance"""
+        """Test the module logger instance."""
 
         if not isinstance(aacgmv2.logger, logging.Logger):
             raise TypeError("Logger incorrect type")
