@@ -1,43 +1,37 @@
-# Copyright (C) 2019 NRL 
+# Copyright (C) 2019 NRL
 # Author: Angeline Burrell
 # Disclaimer: This code is under the MIT license, whose details can be found at
 # the root in the LICENSE file
 #
 # -*- coding: utf-8 -*-
-"""Pythonic wrappers for AACGM-V2 C functions.
+"""Pythonic wrappers for AACGM-V2 C functions."""
 
-"""
-
-from __future__ import division, absolute_import, unicode_literals
 import datetime as dt
 import numpy as np
 import os
-import sys
-import warnings
 
 import aacgmv2
 import aacgmv2._aacgmv2 as c_aacgmv2
 from aacgmv2._aacgmv2 import TRACE, ALLOWTRACE, BADIDEA
 
-if sys.version_info.major == 2:
-    warnings.filterwarnings('error')
 
 def test_time(dtime):
-    """ Test the time input and ensure it is a dt.datetime object
+    """Test the time input and ensure it is a dt.datetime object.
 
     Parameters
     ----------
-    dtime : (unknown)
+    dtime : any
         Time input in an untested format
 
     Returns
     -------
-    dtime : (dt.datetime)
+    dtime : dt.datetime
         Time as a datetime object
 
     Raises
     ------
-    ValueError if time is not a dt.date or dt.datetime object
+    ValueError
+        If time is not a dt.date or dt.datetime object
 
     """
     if isinstance(dtime, dt.date):
@@ -53,26 +47,26 @@ def test_time(dtime):
 
 
 def test_height(height, bit_code):
-    """ Test the input height and ensure it is appropriate for the method
+    """Test the input height and ensure it is appropriate for the method.
 
     Parameters
     ----------
-    height : (float)
+    height : float
         Height to test in km
-    bit_code : (int)
+    bit_code : int
         Code string denoting method to use
 
     Returns
     -------
-    good_height : (boolean)
+    good_height : bool
         True if height and method are appropriate, False if not
 
     Notes
     -----
     Appropriate altitude ranges for the different methods are explored in
     Shepherd (2014).  Summarized, they are:
-    Coefficients: 0-2000 km
-    Tracing: 0-1 Earth Radius
+    1. Coefficients: 0-2000 km
+    2. Tracing: 0-1 Earth Radius
 
     Altitudes below zero will work, but will not provide a good representation
     of the magnetic field because it goes beyond the intended scope of these
@@ -89,8 +83,8 @@ def test_height(height, bit_code):
         aacgmv2.logger.warning('conversion not intended for altitudes < 0 km')
 
     # Test the conditions for using the coefficient method
-    if(height > aacgmv2.high_alt_coeff and
-       not (bit_code & (TRACE|ALLOWTRACE|BADIDEA))):
+    trace_opt = (TRACE | ALLOWTRACE | BADIDEA)
+    if height > aacgmv2.high_alt_coeff and not (bit_code & trace_opt):
         estr = ''.join(['coefficients are not valid for altitudes above ',
                         '{:.0f} km. You '.format(aacgmv2.high_alt_coeff),
                         'must either use field-line tracing (trace=True or',
@@ -110,15 +104,16 @@ def test_height(height, bit_code):
 
     return True
 
+
 def set_coeff_path(igrf_file=False, coeff_prefix=False):
-    """Sets the IGRF_COEFF and AACGMV_V2_DAT_PREFIX environment variables.
+    """Set the IGRF_COEFF and AACGMV_V2_DAT_PREFIX environment variables.
 
     Parameters
-    -----------
-    igrf_file : (str or bool)
+    ----------
+    igrf_file : str or bool
         Full filename of IGRF coefficient file, True to use
         aacgmv2.IGRF_COEFFS, or False to leave as is. (default=False)
-    coeff_prefix : (str or bool)
+    coeff_prefix : str or bool
         Location and file prefix for aacgm coefficient files, True to use
         aacgmv2.AACGM_V2_DAT_PREFIX, or False to leave as is. (default=False)
 
@@ -152,56 +147,55 @@ def set_coeff_path(igrf_file=False, coeff_prefix=False):
 
     return
 
-def convert_latlon(in_lat, in_lon, height, dtime, method_code="G2A", **kwargs):
-    """Converts between geomagnetic coordinates and AACGM coordinates
+
+def convert_latlon(in_lat, in_lon, height, dtime, method_code="G2A"):
+    """Convert between geomagnetic coordinates and AACGM coordinates.
 
     Parameters
-    ------------
-    in_lat : (float)
+    ----------
+    in_lat : float
         Input latitude in degrees N (code specifies type of latitude)
-    in_lon : (float)
+    in_lon : float
         Input longitude in degrees E (code specifies type of longitude)
-    height : (float)
+    height : float
         Altitude above the surface of the earth in km
-    dtime : (datetime)
+    dtime : dt.datetime
         Datetime for magnetic field
-    method_code : (str or int)
+    method_code : str or int
         Bit code or string denoting which type(s) of conversion to perform
-        G2A        - geographic (geodetic) to AACGM-v2
-        A2G        - AACGM-v2 to geographic (geodetic)
-        TRACE      - use field-line tracing, not coefficients
-        ALLOWTRACE - use trace only above 2000 km
-        BADIDEA    - use coefficients above 2000 km
-        GEOCENTRIC - assume inputs are geocentric w/ RE=6371.2
-        (default is "G2A")
+        (default="G2A")
+
+        G2A
+            Geographic (geodetic) to AACGM-v2
+        A2G
+            AACGM-v2 to geographic (geodetic)
+        TRACE
+            Use field-line tracing, not coefficients
+        ALLOWTRACE
+            Use trace only above 2000 km
+        BADIDEA
+            Use coefficients above 2000 km
+        GEOCENTRIC
+            Assume inputs are geocentric w/ RE=6371.2
 
     Returns
     -------
-    out_lat : (float)
+    out_lat : float
         Output latitude in degrees N
-    out_lon : (float)
+    out_lon : float
         Output longitude in degrees E
-    out_r : (float)
+    out_r : float
         Geocentric radial distance (R_Earth) or altitude above the surface of
         the Earth (km)
 
     Raises
     ------
-    ValueError if input is incorrect
-    TypeError or RuntimeError if unable to set AACGMV2 datetime
+    ValueError
+        If input is incorrect.
+    RuntimeError
+        If unable to set AACGMV2 datetime.
 
     """
-    # Handle deprecated keyword arguments
-    for kw in kwargs.keys():
-        if kw not in ['code']:
-            raise TypeError('unexpected keyword argument [{:s}]'.format(kw))
-        else:
-            method_code = kwargs[kw]
-            warnings.warn("".join(["Deprecated keyword argument 'code' will be",
-                                   " removed in version 2.6.1, please update ",
-                                   "your routine to use 'method_code'"]),
-                          category=FutureWarning)
-
     # Test time
     dtime = test_time(dtime)
 
@@ -238,67 +232,73 @@ def convert_latlon(in_lat, in_lon, height, dtime, method_code="G2A", **kwargs):
     try:
         c_aacgmv2.set_datetime(dtime.year, dtime.month, dtime.day, dtime.hour,
                                dtime.minute, dtime.second)
-    except TypeError as terr:
-        raise TypeError("unable to set time for {:}: {:}".format(dtime, terr))
-    except RuntimeError as rerr:
-        raise RuntimeError("unable to set time for {:}: {:}".format(dtime,
-                                                                    rerr))
+    except (TypeError, RuntimeError) as err:
+        raise RuntimeError("cannot set time for {:}: {:}".format(dtime, err))
 
     # convert location
     try:
         lat_out, lon_out, r_out = c_aacgmv2.convert(in_lat, in_lon, height,
                                                     bit_code)
-    except:
-        err = sys.exc_info()[0]
-        estr = "unable to perform conversion at {:.1f},".format(in_lat)
-        estr = "{:s}{:.1f} {:.1f} km, {:} ".format(estr, in_lon, height, dtime)
-        estr = "{:s}using method {:}: {:}".format(estr, bit_code, err)
+    except Exception as err:
+        estr = "".join(["unable to perform conversion at {:.1f}".format(in_lat),
+                        ", {:.1f} {:.1f} km, {:}".format(in_lon, height, dtime),
+                        " using method {:} <{:}>. Recall".format(bit_code, err),
+                        " that AACGMV2 is undefined near the equator."])
         aacgmv2.logger.warning(estr)
         pass
 
     return lat_out, lon_out, r_out
 
-def convert_latlon_arr(in_lat, in_lon, height, dtime, method_code="G2A",
-                       **kwargs):
-    """Converts between geomagnetic coordinates and AACGM coordinates.
+
+def convert_latlon_arr(in_lat, in_lon, height, dtime, method_code="G2A"):
+    """Convert between geomagnetic coordinates and AACGM coordinates.
 
     Parameters
-    ------------
-    in_lat : (np.ndarray or list or float)
+    ----------
+    in_lat : np.ndarray, list, or float
         Input latitude in degrees N (method_code specifies type of latitude)
-    in_lon : (np.ndarray or list or float)
+    in_lon : np.ndarray or list or float
         Input longitude in degrees E (method_code specifies type of longitude)
-    height : (np.ndarray or list or float)
+    height : np.ndarray or list or float
         Altitude above the surface of the earth in km
-    dtime : (datetime)
+    dtime : dt.datetime
         Single datetime object for magnetic field
-    method_code : (int or str)
+    method_code : int or str
         Bit code or string denoting which type(s) of conversion to perform
-        G2A        - geographic (geodetic) to AACGM-v2
-        A2G        - AACGM-v2 to geographic (geodetic)
-        TRACE      - use field-line tracing, not coefficients
-        ALLOWTRACE - use trace only above 2000 km
-        BADIDEA    - use coefficients above 2000 km
-        GEOCENTRIC - assume inputs are geocentric w/ RE=6371.2
-        (default = "G2A")
+        (default="G2A")
+
+        G2A
+            Geographic (geodetic) to AACGM-v2
+        A2G
+            AACGM-v2 to geographic (geodetic)
+        TRACE
+            Use field-line tracing, not coefficients
+        ALLOWTRACE
+            Use trace only above 2000 km
+        BADIDEA
+            Use coefficients above 2000 km
+        GEOCENTRIC
+            Assume inputs are geocentric w/ RE=6371.2
 
     Returns
     -------
-    out_lat : (np.ndarray)
+    out_lat : np.ndarray
         Output latitudes in degrees N
-    out_lon : (np.ndarray)
+    out_lon : np.ndarray
         Output longitudes in degrees E
-    out_r : (np.ndarray)
+    out_r : np.ndarray
         Geocentric radial distance (R_Earth) or altitude above the surface of
         the Earth (km)
 
     Raises
     ------
-    ValueError if input is incorrect
-    TypeError or RuntimeError if unable to set AACGMV2 datetime
+    ValueError
+        If input is incorrect.
+    RuntimeError
+        If unable to set AACGMV2 datetime.
 
     Notes
-    -------
+    -----
     At least one of in_lat, in_lon, and height must be a list or array.
 
     If errors are encountered, NaN or Inf will be included in the input so
@@ -308,60 +308,42 @@ def convert_latlon_arr(in_lat, in_lon, height, dtime, method_code="G2A",
     Multi-dimensional arrays are not allowed.
 
     """
-    # Handle deprecated keyword arguments
-    for kw in kwargs.keys():
-        if kw not in ['code']:
-            raise TypeError('unexpected keyword argument [{:s}]'.format(kw))
-        else:
-            method_code = kwargs[kw]
-            warnings.warn("".join(["Deprecated keyword argument 'code' will be",
-                                   " removed in version 2.6.1, please update ",
-                                   "your routine to use 'method_code'"]),
-                          category=FutureWarning)
-
     # Recast the data as numpy arrays
     in_lat = np.array(in_lat)
     in_lon = np.array(in_lon)
     height = np.array(height)
 
-    # If one or two of these elements is a float or int, create an array
+    # If one or two of these elements is a float, int, or single element array,
+    # create an array equal to the length of the longest input
     test_array = np.array([len(in_lat.shape), len(in_lon.shape),
                            len(height.shape)])
+
     if test_array.max() > 1:
         raise ValueError("unable to process multi-dimensional arrays")
-
-    if test_array.min() == 0:
+    else:
         if test_array.max() == 0:
             aacgmv2.logger.info("".join(["for a single location, consider ",
-                                    "using convert_latlon or get_aacgm_coord"]))
+                                         "using convert_latlon or ",
+                                         "get_aacgm_coord"]))
             in_lat = np.array([in_lat])
             in_lon = np.array([in_lon])
             height = np.array([height])
         else:
-            imax = test_array.argmax()
-            max_shape = in_lat.shape if imax == 0 else (in_lon.shape \
-                                            if imax == 1 else height.shape) 
-            if not test_array[0]:
-                in_lat = np.full(shape=max_shape, fill_value=in_lat)
-            if not test_array[1]:
-                in_lon = np.full(shape=max_shape, fill_value=in_lon)
-            if not test_array[2]:
-                height = np.full(shape=max_shape, fill_value=height)
+            max_len = max([len(arr) for i, arr in enumerate([in_lat, in_lon,
+                                                             height])
+                           if test_array[i] > 0])
+
+            if not test_array[0] or (len(in_lat) == 1 and max_len > 1):
+                in_lat = np.full(shape=(max_len,), fill_value=in_lat)
+            if not test_array[1] or (len(in_lon) == 1 and max_len > 1):
+                in_lon = np.full(shape=(max_len,), fill_value=in_lon)
+            if not test_array[2] or (len(height) == 1 and max_len > 1):
+                height = np.full(shape=(max_len,), fill_value=height)
 
     # Ensure that lat, lon, and height are the same length or if the lengths
     # differ that the different ones contain only a single value
     if not (in_lat.shape == in_lon.shape and in_lat.shape == height.shape):
-        shape_dict = {'lat': in_lat.shape, 'lon': in_lon.shape,
-                      'height': height.shape}
-        ulen = np.unique(shape_dict.values())
-        array_key = [kk for i, kk in enumerate(shape_dict.keys())
-                     if shape_dict[kk] != (1,)]
-        if len(array_key) == 3:
-            raise ValueError('lat, lon, and height arrays are mismatched')
-        elif len(array_key) == 2:
-            if shape_dict[array_key[0]] == shape_dict[array_dict[1]]:
-                raise ValueError('{:s} and {:s} arrays are mismatched'.format(\
-                                                                *array_key))
+        raise ValueError('lat, lon, and height arrays are mismatched')
 
     # Test time
     dtime = test_time(dtime)
@@ -393,16 +375,12 @@ def convert_latlon_arr(in_lat, in_lon, height, dtime, method_code="G2A",
     # Constrain longitudes between -180 and 180
     in_lon = ((in_lon + 180.0) % 360.0) - 180.0
 
-    
     # Set current date and time
     try:
         c_aacgmv2.set_datetime(dtime.year, dtime.month, dtime.day, dtime.hour,
                                dtime.minute, dtime.second)
-    except TypeError as terr:
-        raise TypeError("unable to set time for {:}: {:}".format(dtime, terr))
-    except RuntimeError as rerr:
-        raise RuntimeError("unable to set time for {:}: {:}".format(dtime,
-                                                                    rerr))
+    except (TypeError, RuntimeError) as err:
+        raise RuntimeError("cannot set time for {:}: {:}".format(dtime, err))
 
     try:
         lat_out, lon_out, r_out, bad_ind = c_aacgmv2.convert_arr(list(in_lat),
@@ -426,35 +404,40 @@ def convert_latlon_arr(in_lat, in_lon, height, dtime, method_code="G2A",
 
     return lat_out, lon_out, r_out
 
+
 def get_aacgm_coord(glat, glon, height, dtime, method="ALLOWTRACE"):
-    """Get AACGM latitude, longitude, and magnetic local time
+    """Get AACGM latitude, longitude, and magnetic local time.
 
     Parameters
-    ------------
-    glat : (float)
+    ----------
+    glat : float
         Geodetic latitude in degrees N
-    glon : (float)
+    glon : float
         Geodetic longitude in degrees E
-    height : (float)
+    height : float
         Altitude above the surface of the earth in km
-    dtime : (datetime)
+    dtime : dt.datetime
         Date and time to calculate magnetic location
-    method : (str)
-        String denoting which type(s) of conversion to perform
-        TRACE      - use field-line tracing, not coefficients
-        ALLOWTRACE - use trace only above 2000 km
-        BADIDEA    - use coefficients above 2000 km
-        GEOCENTRIC - assume inputs are geocentric w/ RE=6371.2
-        (default = "TRACE")
+    method : str
+        The type(s) of conversion to perform (default="ALLOWTRACE")
+
+        TRACE
+            Use field-line tracing, not coefficients
+        ALLOWTRACE
+            Use trace only above 2000 km
+        BADIDEA
+            Use coefficients above 2000 km
+        GEOCENTRIC
+            Assume inputs are geocentric w/ RE=6371.2
 
     Returns
     -------
-    mlat : (float)
-        magnetic latitude in degrees N
-    mlon : (float)
-        magnetic longitude in degrees E
-    mlt : (float)
-        magnetic local time in hours
+    mlat : float
+        Magnetic latitude in degrees N
+    mlon : float
+        Magnetic longitude in degrees E
+    mlt : float
+        Magnetic local time in hours
 
     """
     # Initialize method code
@@ -471,35 +454,38 @@ def get_aacgm_coord(glat, glon, height, dtime, method="ALLOWTRACE"):
 
 
 def get_aacgm_coord_arr(glat, glon, height, dtime, method="ALLOWTRACE"):
-    """Get AACGM latitude, longitude, and magnetic local time
+    """Get AACGM latitude, longitude, and magnetic local time.
 
     Parameters
-    ------------
-    glat : (np.array or list)
+    ----------
+    glat : np.array or list
         Geodetic latitude in degrees N
-    glon : (np.array or list)
+    glon : np.array or list
         Geodetic longitude in degrees E
-    height : (np.array or list)
+    height : np.array or list
         Altitude above the surface of the earth in km
-    dtime : (datetime)
+    dtime : dt.datetime
         Date and time to calculate magnetic location
-    method : (str)
-        String denoting which type(s) of conversion to perform
-        TRACE      - use field-line tracing, not coefficients
-        ALLOWTRACE - use trace only above 2000 km
-        BADIDEA    - use coefficients above 2000 km
-        GEOCENTRIC - assume inputs are geocentric w/ RE=6371.2
-        (default = "TRACE")
-        (default = "TRACE")
+    method : str
+        The type(s) of conversion to perform (default="ALLOWTRACE")
+
+        TRACE
+            Use field-line tracing, not coefficients
+        ALLOWTRACE
+            Use trace only above 2000 km
+        BADIDEA
+            Use coefficients above 2000 km
+        GEOCENTRIC
+            Assume inputs are geocentric w/ RE=6371.2
 
     Returns
     -------
-    mlat : (float)
-        magnetic latitude in degrees N
-    mlon : (float)
-        magnetic longitude in degrees E
-    mlt : (float)
-        magnetic local time in hours
+    mlat : float
+        Magnetic latitude in degrees N
+    mlon : float
+        Magnetic longitude in degrees E
+    mlt : float
+        Magnetic local time in hours
 
     """
     # Initialize method code
@@ -512,35 +498,41 @@ def get_aacgm_coord_arr(glat, glon, height, dtime, method="ALLOWTRACE"):
     if np.any(np.isfinite(mlon)):
         # Get magnetic local time
         mlt = convert_mlt(mlon, dtime, m2a=False)
-        if not isinstance(mlt, type(mlat)):
-            mlt = np.array([mlt])
     else:
         mlt = np.full(shape=len(mlat), fill_value=np.nan)
 
     return mlat, mlon, mlt
 
+
 def convert_str_to_bit(method_code):
-    """convert string code specification to bit code specification
+    """Convert string code specification to bit code specification.
 
     Parameters
-    ------------
-    method_code : (str)
-        Bitwise code for passing options into converter (default=0)
-        G2A        - geographic (geodetic) to AACGM-v2
-        A2G        - AACGM-v2 to geographic (geodetic)
-        TRACE      - use field-line tracing, not coefficients
-        ALLOWTRACE - use trace only above 2000 km
-        BADIDEA    - use coefficients above 2000 km
-        GEOCENTRIC - assume inputs are geocentric w/ RE=6371.2
+    ----------
+    method_code : str
+        Bitwise code for passing options into converter:
+
+        G2A
+            Geographic (geodetic) to AACGM-v2
+        A2G
+            AACGM-v2 to geographic (geodetic)
+        TRACE
+            Use field-line tracing, not coefficients
+        ALLOWTRACE
+            Use trace only above 2000 km
+        BADIDEA
+            Use coefficients above 2000 km
+        GEOCENTRIC
+            Assume inputs are geocentric w/ RE=6371.2
 
     Returns
-    --------
-    bit_code : (int)
+    -------
+    bit_code : int
         Method code specification in bits
 
     Notes
-    --------
-    Multiple codes should be seperated by pipes '|'.  Invalid parts of the code
+    -----
+    Multiple codes should be seperated by pipes `|`.  Invalid parts of the code
     are ignored and no code defaults to 'G2A'.
 
     """
@@ -559,27 +551,28 @@ def convert_str_to_bit(method_code):
 
     return bit_code
 
+
 def convert_bool_to_bit(a2g=False, trace=False, allowtrace=False,
                         badidea=False, geocentric=False):
-    """convert boolian flags to bit code specification
+    """Convert boolian flags to bit code specification.
 
     Parameters
     ----------
-    a2g : (bool)
+    a2g : bool
         True for AACGM-v2 to geographic (geodetic), False otherwise
         (default=False)
-    trace : (bool)
+    trace : bool
         If True, use field-line tracing, not coefficients (default=False)
-    allowtrace : (bool)
+    allowtrace : bool
         If True, use trace only above 2000 km (default=False)
-    badidea : (bool)
+    badidea : bool
         If True, use coefficients above 2000 km (default=False)
-    geocentric : (bool)
+    geocentric : bool
         True for geodetic, False for geocentric w/RE=6371.2 (default=False)
 
     Returns
-    --------
-    bit_code : (int)
+    -------
+    bit_code : int
         code specification in bits
 
     """
@@ -597,26 +590,27 @@ def convert_bool_to_bit(a2g=False, trace=False, allowtrace=False,
 
     return bit_code
 
+
 def convert_mlt(arr, dtime, m2a=False):
-    """Converts between magnetic local time (MLT) and AACGM-v2 longitude
+    """Converts between magnetic local time (MLT) and AACGM-v2 longitude.
 
     Parameters
-    ------------
-    arr : (array-like or float)
+    ----------
+    arr : array-like or float
         Magnetic longitudes (degrees E) or MLTs (hours) to convert
-    dtime : (array-like or datetime.datetime)
+    dtime : array-like or dt.datetime
         Date and time for MLT conversion in Universal Time (UT).
-    m2a : (bool)
+    m2a : bool
         Convert MLT to AACGM-v2 longitude (True) or magnetic longitude to MLT
         (False).  (default=False)
 
     Returns
-    --------
-    out : (np.ndarray)
+    -------
+    out : np.ndarray
         Converted coordinates/MLT in degrees E or hours (as appropriate)
 
     Notes
-    -------
+    -----
     This routine previously based on Laundal et al. 2016, but now uses the
     improved calculation available in AACGM-V2.4.
 
@@ -661,6 +655,7 @@ def convert_mlt(arr, dtime, m2a=False):
             out = c_aacgmv2.inv_mlt_convert(years[0], months[0], days[0],
                                             hours[0], minutes[0], seconds[0],
                                             arr[0])
+            out = np.array([out])
         else:
             out = c_aacgmv2.inv_mlt_convert_arr(years, months, days, hours,
                                                 minutes, seconds, arr)
